@@ -1,12 +1,12 @@
 package App::HasPrereqs;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use Config::IniFiles;
 use Module::Path::More qw(module_path);
@@ -114,7 +114,7 @@ App::HasPrereqs - Check whether your Perl installation has prerequisites in dist
 
 =head1 VERSION
 
-This document describes version 0.06 of App::HasPrereqs (from Perl distribution App-HasPrereqs), released on 2014-12-27.
+This document describes version 0.07 of App::HasPrereqs (from Perl distribution App-HasPrereqs), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -125,20 +125,18 @@ This document describes version 0.06 of App::HasPrereqs (from Perl distribution
 
 =head2 has_prereqs(%args) -> [status, msg, result, meta]
 
-Check whether your Perl installation has prerequisites in dist.ini.
+{en_US Check whether your Perl installation has prerequisites in dist.ini}.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<library> => I<array>
+=item * B<library> => I<array[str]>
 
-Add directory to @INC.
+{en_US Add directory to @INC}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -148,7 +146,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -156,7 +154,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-HasPre
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-HasPrereqs>.
+Source repository is at L<https://github.com/perlancar/perl-App-HasPrereqs>.
 
 =head1 BUGS
 
@@ -172,7 +170,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
